package
Version:
v1.1.2
Opens a new window with list of versions in this module.
Published: Apr 12, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package httpclient provides a simple HTTP GET function for statusline API calls.
GetFn is the type for HTTP GET functions.
type Response struct {
StatusCode int
Body []byte
}
Response holds HTTP response data.
Get performs an HTTP GET request with context timeout.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.